@@ -16,7 +16,12 @@ from ansible.plugins.action import ActionBase
 
 TEMPLATE_KWARGS = {}
 
-_argspec = inspect.getargspec(ansible.template.Templar.template)
+try:
+    # inspect.getfullargspec()  Added: 3.0
+    _argspec = inspect.getfullargspec(ansible.template.Templar.template)
+except AttributeError:
+    # inspect.getargspec()      Added: 2.1  Deprecated: 3.0  Removed: 3.11
+    _argspec = inspect.getargspec(ansible.template.Templar.template)
 if 'bare_deprecated' in _argspec.args:
     TEMPLATE_KWARGS['bare_deprecated'] = False
 
