@@ -1,9 +1,13 @@
-import mock
 import textwrap
 import subprocess
 import sys
 import unittest
 
+try:
+    from unittest import mock
+except ImportError:
+    import mock
+
 import mitogen.master
 import testlib
 
